==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/el/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Επιβεβαιώστε μαζική διαγραφή περιουσιακών στοιχείων',
  'bulk_delete_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική διαγραφή παρακάτω. Μόλις διαγραφεί, αυτά τα περιουσιακά στοιχεία μπορούν να αποκατασταθούν, αλλά αυτά δεν θα είναι πλέον συσχετιζόμενα με οποιοσδήποτε χρήστη που τους έχει ανατεθεί.',
  'bulk_delete_warn'	=> 'Πρόκειται να διαγράψετε: asset_count περιουσιακών στοιχείων.',
	'bulk_update'		=> 'Μαζική ενημέρωση παγίων',
	'bulk_update_help'	=> 'Αυτή η φόρμα επιτρέπει την ενημέρωση πολλαπλών παγίων ταυτόχρονα. Μόνο συμπληρώστε τα πεδία που θέλετε να αλλάξετε. Οποιαδήποτε πεδίο αριστερά μείνει κενό θα παραμείνει ως αμετάβλητο. ',
	'bulk_update_warn'	=> 'Είστε έτοιμοι να επεξεργαστείτε τις ιδιότητες του: asset_count περιουσιακών στοιχείων.',
    'checkedout_to'		=> 'Ανάθεση σε',
    'checkout_date'		=> 'Ημερομηνία αποχώρησης',
    'checkin_date'		=> 'Ημερομηνία άφιξης',
    'checkout_to'		=> 'Ημερομηνία αποχώρησης σε',
    'cost'				=> 'Κόστος αγοράς',
    'create'			=> 'Δημιουργία παγίου',
    'date'				=> 'Ημερομηνία αγοράς',
    'depreciation'	    => 'Υποτίμηση',
    'depreciates_on'	=> 'Αποσβέσεις σε',
    'default_location'	=> 'Προεπιλεγμένη τοποθεσία',
    'eol_date'			=> 'EOL ημερομηνία',
    'eol_rate'			=> 'EOL δείκτης',
    'expected_checkin'  => 'Αναμενώμενη ημέρα άφιξης',
    'expires'			=> 'Λήξη',
    'fully_depreciated'	=> 'Έχει πλήρως αποσβεστεί',
    'help_checkout'		=> 'Αν θέλετε να εκχωρήσετε αυτό το πάγιο αμέσως, επιλέξτε «Έτοιμοι να αναπτύξετε» από την παρακάτω λίστα. ',
    'mac_address'		=> 'Διεύθυνση MAC',
    'manufacturer'		=> 'Κατασκευαστής',
    'model'				=> 'Μοντέλο',
    'months'			=> 'μήνες',
    'name'				=> 'Ονομασία του παγίου',
    'notes'				=> 'Σημειώσεις',
    'order'				=> 'Αριθμός παραγγελίας',
    'qr'				=> 'Κωδικός QR',
    'requestable'		=> 'Οι χρήστες μπορούν να αιτηθούν το πάγιο',
    'select_statustype'	=> 'Επιλέξτε Τύπο Κατάστασης',
    'serial'			=> 'Σειριακός',
    'status'			=> 'Κατάσταση',
    'tag'				=> 'Ετικέτα πόρων',
    'update'			=> 'Ενημέρωση παγίου',
    'warranty'			=> 'Εγγύηση',
		'warranty_expires'		=> 'Λήξη Εγγύησης',
    'years'				=> 'έτη',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/el/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Επιβεβαιώστε μαζική διαγραφή περιουσιακών στοιχείων',
  'bulk_delete_help'	=> 'Εξετάστε τα περιουσιακά στοιχεία για μαζική διαγραφή παρακάτω. Μόλις διαγραφεί, αυτά τα περιουσιακά στοιχεία μπορούν να αποκατασταθούν, αλλά αυτά δεν θα είναι πλέον συσχετιζόμενα με οποιοσδήποτε χρήστη που τους έχει ανατεθεί.',
  'bulk_delete_warn'	=> 'Πρόκειται να διαγράψετε: asset_count περιουσιακών στοιχείων.',
    'bulk_update'		=> 'Μαζική ενημέρωση παγίων',
    'bulk_update_help'	=> 'Αυτή η φόρμα επιτρέπει την ενημέρωση πολλαπλών παγίων ταυτόχρονα. Μόνο συμπληρώστε τα πεδία που θέλετε να αλλάξετε. Οποιαδήποτε πεδίο αριστερά μείνει κενό θα παραμείνει ως αμετάβλητο. ',
    'bulk_update_warn'	=> 'Είστε έτοιμοι να επεξεργαστείτε τις ιδιότητες του: asset_count περιουσιακών στοιχείων.',
    'checkedout_to'		=> 'Ανάθεση σε',
    'checkout_date'		=> 'Ημερομηνία αποχώρησης',
    'checkin_date'		=> 'Ημερομηνία άφιξης',
    'checkout_to'		=> 'Ημερομηνία αποχώρησης σε',
    'cost'				=> 'Κόστος αγοράς',
    'create'			=> 'Δημιουργία παγίου',
    'date'				=> 'Ημερομηνία αγοράς',
    'depreciation'	    => 'Υποτίμηση',
    'depreciates_on'	=> 'Αποσβέσεις σε',
    'default_location'	=> 'Προεπιλεγμένη τοποθεσία',
    'eol_date'			=> 'EOL ημερομηνία',
    'eol_rate'			=> 'EOL δείκτης',
    'expected_checkin'  => 'Αναμενώμενη ημέρα άφιξης',
    'expires'			=> 'Λήξη',
    'fully_depreciated'	=> 'Έχει πλήρως αποσβεστεί',
    'help_checkout'		=> 'Αν θέλετε να εκχωρήσετε αυτό το πάγιο αμέσως, επιλέξτε «Έτοιμοι να αναπτύξετε» από την παρακάτω λίστα. ',
    'mac_address'		=> 'Διεύθυνση MAC',
    'manufacturer'		=> 'Κατασκευαστής',
    'model'				=> 'Μοντέλο',
    'months'			=> 'μήνες',
    'name'				=> 'Ονομασία του παγίου',
    'notes'				=> 'Σημειώσεις',
    'order'				=> 'Αριθμός παραγγελίας',
    'qr'				=> 'Κωδικός QR',
    'requestable'		=> 'Οι χρήστες μπορούν να αιτηθούν το πάγιο',
    'select_statustype'	=> 'Επιλέξτε Τύπο Κατάστασης',
    'serial'			=> 'Σειριακός',
    'status'			=> 'Κατάσταση',
    'tag'				=> 'Ετικέτα πόρων',
    'update'			=> 'Ενημέρωση παγίου',
    'warranty'			=> 'Εγγύηση',
        'warranty_expires'		=> 'Λήξη Εγγύησης',
    'years'				=> 'έτη',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
